@@ -16,9 +16,18 @@ extern char * PixmapPath ;
 /* empty by default; can be written to */
 extern char * TilePath ;
 
+/* empty by default; can be written to */
+extern char * HighlightPath ;
+
 /* defaults to true */
 extern bool NewLeaving ;
 
+/* defaults to false */
+extern bool ClickOnly ;
+
+/* defaults to true */
+extern bool AutoScale ;
+
 extern int Options_Argc ;
 extern char * Options_Argv [] ;
 
